@@ -229,6 +229,10 @@ def space(
         help="list of integers in which each odd indexed element starts"
         + " a range and the consecutive closes it (start counting from 1)",
     ),
+    power_of_2: Optional[List[str]] = typer.Option(
+        None,
+        help="list of 'y'/'n' where y indicates that the corresponding, in order, parameter must be a power of 2",
+    ),
     param_initial_values: Optional[List[int]] = typer.Option(
         None,
         help="state initial values for parameters which are guaranteed to synthesize/implement",
@@ -333,7 +337,11 @@ def space(
         )
 
     result = optimize(
-        fitness_evaluator, ranges_dict, metrics, optimization_runtime,
+        fitness_evaluator,
+        ranges_dict,
+        metrics,
+        optimization_runtime,
+        power_of_2,
     )
     print("Optimization Result: " + str(result))
 
